@@ -4,9 +4,9 @@
 """
 
 __title__ = "song-edit"
-__full_title__ = "Sqd's Song Editor"
+__full_title__ = "sqd-song-edit"
 __description__ = "edit song cover art and metadeta easily!"
-__version__ = "1.0.1"
+__version__ = "1.1.1"
 
 __author__ = "SqdNoises"
 __license__ = "MIT"
